#!/bin/bash

# configuration
EXEC_DIRECTORY="/home/xavier/packages" 
SVN_URL="svn://svn.tuxfamily.org/svnroot/qet/qet/branches/0.3"
PACKAGE_NAME="branche-0.3"

CHECKOUT_DIRECTORY="${EXEC_DIRECTORY}/checkout/${PACKAGE_NAME}" 
BUILD_DIRECTORY="${EXEC_DIRECTORY}/builds/${PACKAGE_NAME}"
PACKAGES_DIRECTORY="${EXEC_DIRECTORY}/packages"
NORMAL_USER="xavier" 
QMAKE_BIN="/usr/bin/qmake"

# traitements
if [ $(id -u) -ne "0" ]; then
	echo "Vous devez etre root pour executer ce script." 
	exit 5
fi


# Supprime l'ancien repertoire d'installation
rm -rf "${BUILD_DIRECTORY}"

# S'assure de la presence du dossier de checkout
if [ ! -d "${CHECKOUT_DIRECTORY}" ]; then
	su "${NORMAL_USER}" -c "svn co ${SVN_URL} ${CHECKOUT_DIRECTORY}"
	if [ $? -ne 0 ]; then
		echo "Le check out a echoue."
	fi

	# patche le fichier qelectrotech.pro
	cd "${CHECKOUT_DIRECTORY}"
	su "${NORMAL_USER}" -c "patch -p0 < ${EXEC_DIRECTORY}/qelectrotech.pro-${PACKAGE_NAME}.diff"
fi

# Se rend dans le dossier de travail
cd ${CHECKOUT_DIRECTORY} 

# Retablit les fichiers man si necessaires
gz_man_count=$(find man -name "*.gz" | wc -l)
if [ "${gz_man_count}" -gt 0 ]; then
	echo "Il y a ${gz_man_count} fichiers man compresses. Decompression" 
	su "${NORMAL_USER}" "./man/uncompress_man_pages.sh"
fi

# compile en tant qu'utilisateur lambda
su "${NORMAL_USER}" -c "svn up && ${QMAKE_BIN} && make release -j 2 && make install"
if [ $? -ne 0 ]; then
	echo "Erreur pendant la compilation"
	exit 4
fi

# recupere la version SVN dans le dossier de travail
current_svn_version=$(LANG=C svn info | grep ^Revision | cut "-d " -f2)

# installe QET dans le repertoire d'installation
"${EXEC_DIRECTORY}/makepkg_from_build.sh" "${BUILD_DIRECTORY}" "${EXEC_DIRECTORY}/qelectrotech.tgz"
exit_code=$?
if [ $exit_code -ne 0 ]; then
	echo "Probleme lors de la realisation du paquet ($exit_code)" 
	exit 3
fi

new_name="qelectrotech-${PACKAGE_NAME}-rev-${current_svn_version}-i386-1.tgz"
mv "${EXEC_DIRECTORY}/qelectrotech.tgz" "${PACKAGES_DIRECTORY}/$new_name"
chown "${NORMAL_USER}" "${PACKAGES_DIRECTORY}/$new_name"
chmod g+w "${PACKAGES_DIRECTORY}/$new_name" 

